
# Slot: affected by


describes an entity of which the state or quality is affected by another existing entity.

URI: [biolink:affected_by](https://w3id.org/biolink/vocab/affected_by)


## Domain and Range

[NamedThing](NamedThing.md) &#8594;  <sub>0..\*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children

 *  [disrupted by](disrupted_by.md)
 *  [entity regulated by entity](entity_regulated_by_entity.md)
 *  [process regulated by process](process_regulated_by_process.md)

## Used by

